"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.getTemplateUrlMapping = exports.createApp = void 0;
const child_process_1 = require("child_process");
const fs_1 = __importDefault(require("fs"));
const path_1 = __importDefault(require("path"));
const spinner_1 = __importDefault(require("../outputs/spinner"));
async function createApp(templateUrl, folderName) {
    const spinner = new spinner_1.default();
    try {
        spinner.spin("Creating dapp ");
        (0, child_process_1.execSync)(`git clone --quiet ${templateUrl} ${folderName}`);
        cleanUpFiles(folderName);
        spinner.success("Dapp created !");
    }
    catch (error) {
        console.log("Error: ", error.message);
    }
    finally {
        spinner.stop();
    }
}
exports.createApp = createApp;
function cleanUpFiles(folderName) {
    fs_1.default.rmSync(path_1.default.join(process.cwd(), folderName, ".git"), {
        recursive: true,
        force: true,
    });
}
function getTemplateUrlMapping(alias) {
    if (alias === "Portfolio") {
        return "https://github.com/spheronFdn/portfolio-template";
    }
    else if (alias === "NFT Drop") {
        return "https://github.com/spheronFdn/react-boilerplate";
    }
    else if (alias === "React") {
        return "https://github.com/spheronFdn/react-boilerplate";
    }
    else if (alias === "Next.js") {
        return "https://github.com/spheronFdn/react-boilerplate";
    }
    throw new Error("Mapping for template not found");
}
exports.getTemplateUrlMapping = getTemplateUrlMapping;
