"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.upload = void 0;
const configuration_1 = __importDefault(require("../configuration"));
const spheron_storage_dusan_1 = __importStar(require("spheron-storage-dusan"));
const cli_progress_1 = __importDefault(require("cli-progress"));
const utils_1 = require("../utils");
const spinner_1 = __importDefault(require("../outputs/spinner"));
async function upload(rootPath, protocol, organizationId, projectName) {
    const spinner = new spinner_1.default();
    try {
        spinner.spin("Upload ");
        const jwtToken = await (0, utils_1.readFromJsonFile)("jwtToken", configuration_1.default.configFilePath);
        if (!jwtToken) {
            throw new Error("Authorization failed. Please execute login command first");
        }
        const client = new spheron_storage_dusan_1.default({ token: jwtToken });
        let uploadedBytes = 0;
        const progressBar = new cli_progress_1.default.SingleBar({
            format: "Uploading [{bar}] {percentage}% | ETA: {eta_formatted} | {value}/{total} bytes",
            stopOnComplete: true,
        });
        let uploadStarted = false;
        const fileType = await (0, utils_1.getFileType)(rootPath);
        console.log(`Uploading ${fileType} `);
        const { uploadId, bucketId, protocolLink, dynamicLinks } = await client.upload(rootPath, {
            protocol: mapProtocol(protocol),
            name: projectName,
            organizationId,
            onUploadInitiated: (deploymentId) => {
                console.log("Upload started, id of deployment: " + deploymentId);
            },
            onChunkUploaded(uploadedSize, totalSize) {
                if (!uploadStarted) {
                    uploadStarted = true;
                    progressBar.start(totalSize, 0);
                }
                uploadedBytes += uploadedSize;
                progressBar.update(uploadedBytes);
            },
        });
        console.log("Upload finished, here is upload details:");
        console.log(`Upload ID: ${uploadId}`);
        console.log(`Bucket ID: ${bucketId}`);
        console.log(`Protocol Link: ${protocolLink}`);
        console.log(`Dynamic Links:", ${dynamicLinks.join(", ")}`);
        spinner.success("Upload finished !");
    }
    catch (error) {
        console.log(`Error: ${error.message}`);
        if (protocol == "Arweave") {
            console.log(`Arweave is not enabled for starter plan, please upgrade your plan to pro to start uploading your files to Arweave.\nPlease feel free to contact our team on Discord if you have any questions.`);
        }
    }
    finally {
        spinner.stop();
    }
}
exports.upload = upload;
function mapProtocol(protocol) {
    if (protocol === "IPFS") {
        return spheron_storage_dusan_1.ProtocolEnum.IPFS;
    }
    else if (protocol === "Filecoin") {
        return spheron_storage_dusan_1.ProtocolEnum.FILECOIN;
    }
    else if (protocol === "Arweave") {
        return spheron_storage_dusan_1.ProtocolEnum.ARWEAVE;
    }
    return spheron_storage_dusan_1.ProtocolEnum.IPFS;
}
