"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.promptForCreateApp = exports.promptForInit = exports.promptForCreateOrganization = exports.promptForUploadFile = exports.promptForLogin = void 0;
const create_app_1 = require("../commands/create-app");
const init_1 = require("../commands/init");
const inquirer = require("inquirer");
async function promptForLogin() {
    const result = await inquirer.prompt([
        {
            type: "list",
            name: "provider",
            message: "Select your provider:",
            choices: ["github", "gitlab", "bitbucket"],
        },
    ]);
    return result;
}
exports.promptForLogin = promptForLogin;
async function promptForUploadFile() {
    const pathSegments = process.cwd().split("/");
    const defaultProject = pathSegments[pathSegments.length - 1];
    const questions = [
        {
            type: "input",
            name: "path",
            message: "Path to file:",
            default: "./",
        },
        {
            type: "list",
            name: "protocol",
            message: "Upload protocol:",
            choices: ["Arweave", "Filecoin", "IPFS"],
        },
        {
            type: "input",
            name: "project",
            message: "Project name:",
            default: defaultProject,
        },
        {
            type: "input",
            name: "organizationId",
            message: "Organization where project will be created (optional):",
        },
    ];
    return inquirer.prompt(questions);
}
exports.promptForUploadFile = promptForUploadFile;
async function promptForCreateOrganization() {
    const defaultName = `org-${Math.floor(Math.random() * 900) + 100}`;
    const questions = [
        {
            type: "input",
            name: "name",
            message: "Name of the organization:",
            default: defaultName,
        },
        {
            type: "input",
            name: "username",
            message: "Username of the organization:",
            default: defaultName,
        },
    ];
    return inquirer.prompt(questions);
}
exports.promptForCreateOrganization = promptForCreateOrganization;
async function promptForInit() {
    const pathSegments = process.cwd().split("/");
    const defaultProject = pathSegments[pathSegments.length - 1];
    const questions = [
        {
            type: "input",
            name: "project",
            message: "Project name:",
            default: defaultProject,
        },
        {
            type: "list",
            name: "protocol",
            choices: ["Arweave", "Filecoin", "IPFS"],
            message: "Upload protocol:",
        },
        {
            type: "input",
            name: "path",
            message: "Relative path to content:",
            default: "./",
        },
        {
            type: "list",
            name: "framework",
            choices: Object.values(init_1.FrameworkOptions),
            message: "Framework:",
            default: "static",
        },
    ];
    return inquirer.prompt(questions);
}
exports.promptForInit = promptForInit;
async function promptForCreateApp(appName) {
    inquirer
        .prompt([
        {
            type: "list",
            name: "projectType",
            message: "What type of project do you want to create?",
            choices: ["Default app", "Start from a template"],
        },
    ])
        .then((answers) => {
        if (answers.projectType === "Default app") {
            inquirer
                .prompt([
                {
                    type: "list",
                    name: "templateType",
                    message: "Choose a default app type:",
                    choices: ["React", "Next.js"],
                },
                {
                    type: "input",
                    name: "project",
                    message: "Project name:",
                    default: function (answers) {
                        if (appName) {
                            return appName;
                        }
                        if (answers.templateType === "React") {
                            return "my-react-app";
                        }
                        else if (answers.templateType === "Next.js") {
                            return "my-nextjs-app";
                        }
                        return "";
                    },
                },
            ])
                .then(async (answers) => {
                console.log(`Creating a new default ${answers.templateType} project name ${answers.project}. Time to become a wizard 🔮`);
                const url = (0, create_app_1.getTemplateUrlMapping)(answers.templateType);
                await (0, create_app_1.createApp)(url, answers.project);
            });
        }
        else if (answers.projectType === "Start from a template") {
            inquirer
                .prompt([
                {
                    type: "list",
                    name: "templateType",
                    message: "Choose a template:",
                    choices: ["Portfolio", "NFT Drop"],
                },
                {
                    type: "input",
                    name: "project",
                    message: "Project name:",
                    default: function (answers) {
                        if (appName) {
                            return appName;
                        }
                        if (answers.templateType === "Portfolio") {
                            return "my-portfolio-app";
                        }
                        else if (answers.templateType === "NFT Drop") {
                            return "my-nft-drop-app";
                        }
                        return "";
                    },
                },
            ])
                .then(async (answers) => {
                if (!answers.project) {
                    throw new Error("Project name was not provided");
                }
                console.log(`Creating a new spheron project from template ${answers.templateType} with project name ${answers.project}. Time to become a wizard 🔮`);
                const url = (0, create_app_1.getTemplateUrlMapping)(answers.templateType);
                await (0, create_app_1.createApp)(url, answers.project);
            });
        }
    });
}
exports.promptForCreateApp = promptForCreateApp;
